==> giada_1.2.1.orig.tar.xz: giada-1.2.1/src/gui/elems/config/tabBehaviors.h <==
/* -----------------------------------------------------------------------------
 *
 * Giada - Your Hardcore Loopmachine
 *
 * -----------------------------------------------------------------------------
 *
 * Copyright (C) 2010-2025 Giovanni A. Zuliani | Monocasual Laboratories
 *
 * This file is part of Giada - Your Hardcore Loopmachine.
 *
 * Giada - Your Hardcore Loopmachine is free software: you can
 * redistribute it and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation, either
 * version 3 of the License, or (at your option) any later version.
 *
 * Giada - Your Hardcore Loopmachine is distributed in the hope that it
 * will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Giada - Your Hardcore Loopmachine. If not, see
 * <http://www.gnu.org/licenses/>.
 *
 * -------------------------------------------------------------------------- */

#ifndef GE_TAB_BEHAVIORS_H
#define GE_TAB_BEHAVIORS_H

#include "deps/geompp/src/rect.hpp"
#include "glue/config.h"
#include "gui/elems/basics/check.h"
#include <FL/Fl_Group.H>

namespace giada::v
{
class geTabBehaviors : public Fl_Group
{
public:
	geTabBehaviors(geompp::Rect<int>);

private:
	c::config::BehaviorsData m_data;

	geCheck* m_chansStopOnSeqHalt;
	geCheck* m_treatRecsAsLoops;
	geCheck* m_inputMonitorDefaultOn;
	geCheck* m_overdubProtectionDefaultOn;
};
} // namespace giada::v

#endif

==> giada_1.3.0.orig.tar.xz: giada-1.3.0/src/gui/elems/config/tabBehaviors.h <==
/* -----------------------------------------------------------------------------
 *
 * Giada - Your Hardcore Loopmachine
 *
 * -----------------------------------------------------------------------------
 *
 * Copyright (C) 2010-2025 Giovanni A. Zuliani | Monocasual Laboratories
 *
 * This file is part of Giada - Your Hardcore Loopmachine.
 *
 * Giada - Your Hardcore Loopmachine is free software: you can
 * redistribute it and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation, either
 * version 3 of the License, or (at your option) any later version.
 *
 * Giada - Your Hardcore Loopmachine is distributed in the hope that it
 * will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Giada - Your Hardcore Loopmachine. If not, see
 * <http://www.gnu.org/licenses/>.
 *
 * -------------------------------------------------------------------------- */

#ifndef GE_TAB_BEHAVIORS_H
#define GE_TAB_BEHAVIORS_H

#include "src/deps/geompp/src/rect.hpp"
#include "src/glue/config.h"
#include "src/gui/elems/basics/check.h"
#include <FL/Fl_Group.H>

namespace giada::v
{
class geTabBehaviors : public Fl_Group
{
public:
	geTabBehaviors(geompp::Rect<int>);

private:
	c::config::BehaviorsData m_data;

	geCheck* m_chansStopOnSeqHalt;
	geCheck* m_treatRecsAsLoops;
	geCheck* m_inputMonitorDefaultOn;
	geCheck* m_overdubProtectionDefaultOn;
};
} // namespace giada::v

#endif
